@@ -1,7 +1,7 @@
 package App::CPANSQLiteUtils;
 
 our $DATE = '2015-01-10'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -262,11 +262,13 @@ $SPEC{list_local_cpan_packages} = {
             summary => 'Filter by author',
             schema => 'str*',
             cmdline_aliases => {a=>{}},
+            completion => \&_complete_cpanid,
         },
         dist => {
             summary => 'Filter by distribution',
             schema => 'str*',
             cmdline_aliases => {d=>{}},
+            completion => \&_complete_dist,
         },
     },
     result_naked => 1,
@@ -337,6 +339,7 @@ $SPEC{list_local_cpan_dists} = {
             summary => 'Filter by author',
             schema => 'str*',
             cmdline_aliases => {a=>{}},
+            completion => \&_complete_cpanid,
         },
     },
     result_naked => 1,
@@ -610,7 +613,7 @@ App::CPANSQLiteUtils - Some utilities that query local CPAN::SQLite database
 
 =head1 VERSION
 
-This document describes version 0.02 of App::CPANSQLiteUtils (from Perl distribution App-CPANSQLiteUtils), released on 2015-01-10.
+This document describes version 0.03 of App::CPANSQLiteUtils (from Perl distribution App-CPANSQLiteUtils), released on 2015-01-10.
 
 =head1 SYNOPSIS
 
